@@ -203,17 +203,17 @@ impl Logic for MemoryInterfaceGenerator {
         self.cmd_fifo.read.next = false;
         self.write_fifo.read.next = false;
         self.read_fifo.write.next = false;
-        self.reset_out.next = false.into();
+        self.reset_out.next = NO_RESET;
         match self.state.q.val() {
             State::Init => {
                 self.state.d.next = State::Calibrating;
                 self.timer.d.next = 100_usize.into();
             }
             State::Calibrating => {
-                if (self.timer.q.val() == 0_usize) & !self.reset.val() {
+                if self.timer.q.val() == 0_usize {
                     self.calib.d.next = true;
                     self.state.d.next = State::Idle;
-                    self.reset_out.next = true.into();
+                    self.reset_out.next = RESET;
                 }
             }
             State::Idle => {
