@@ -27,7 +27,7 @@ impl<const R: usize, const C: usize, const P: u32, const D: usize, const A: usiz
         self.bus_read.empty.next = self.controller.empty.val();
         self.bus_read.almost_empty.next = self.controller.empty.val();
         self.controller.read.next = self.bus_read.read.val();
-        self.controller.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, controller);
         self.controller.ram_clock.next = self.ram_clock.val();
         SDRAMDriver::<D>::link(&mut self.sdram, &mut self.controller.sdram);
     }
