@@ -206,6 +206,9 @@ impl Logic for ADS868XSimulator {
                 self.state.d.next = ADS868XState::Waiting;
                 self.conversion_counter.d.next = self.conversion_counter.q.val() + 1_u32;
             }
+            _ => {
+                self.state.d.next = ADS868XState::Ready;
+            }
         }
     }
 }
