@@ -184,6 +184,9 @@ impl Logic for MAX31856Simulator {
                     self.state.d.next = MAX31856State::WriteCmd;
                 }
             }
+            _ => {
+                self.state.d.next = MAX31856State::Start;
+            }
         }
         // Warning! There is a contention between writes from the SPI bus and
         // writes from the DAQ...  A more sophisticated model would segment
@@ -218,6 +221,9 @@ impl Logic for MAX31856Simulator {
                 self.reg_ram.write_enable.next = true;
                 self.dstate.d.next = DAQState::Idle;
             }
+            _ => {
+                self.dstate.d.next = DAQState::Idle;
+            }
         }
     }
 }
