@@ -10,6 +10,7 @@ pub struct MuxedMAX31856Simulators {
     pub mux: MuxSlaves<8, 3>,
     pub addr: Signal<In, Bits<3>>,
     pub clock: Signal<In, Clock>,
+    pub reset: Signal<In, Reset>,
     adcs: Vec<MAX31856Simulator>,
 }
 
@@ -20,6 +21,7 @@ impl MuxedMAX31856Simulators {
             mux: Default::default(),
             addr: Default::default(),
             clock: Default::default(),
+            reset: Default::default(),
             adcs: (0..8).map(|_| MAX31856Simulator::new(config)).collect(),
         }
     }
@@ -32,6 +34,7 @@ impl Logic for MuxedMAX31856Simulators {
         self.mux.sel.next = self.addr.val();
         for i in 0_usize..8_usize {
             self.adcs[i].clock.next = self.clock.val();
+            self.adcs[i].reset.next = self.reset.val();
             SPIWiresMaster::join(&mut self.mux.to_slaves[i], &mut self.adcs[i].wires);
         }
     }
@@ -44,6 +47,7 @@ fn test_mux_is_synthesizable() {
     uut.wires.link_connect_dest();
     uut.addr.connect();
     uut.clock.connect();
+    uut.reset.connect();
     uut.connect_all();
     yosys_validate("mux_31865", &generate_verilog(&uut)).unwrap();
 }
