@@ -372,6 +372,9 @@ impl<const R: usize, const C: usize, const A: usize, const D: usize> Logic
                     }
                 }
             }
+            _ => {
+                self.state.d.next = BankState::Boot;
+            }
         }
         if self.refresh_counter.q.val() >= self.t_refresh_max.val() {
             self.state.d.next = BankState::Error;
