@@ -221,6 +221,9 @@ impl<const R: usize, const C: usize, const A: usize, const D: usize> Logic
             MasterState::Ready => {
                 self.test_ready.next = true;
             }
+            _ => {
+                self.state.d.next = MasterState::Boot;
+            }
         }
         // Any banks that are in error mean the chip is in error.
         for i in 0_usize..4 {
@@ -455,6 +458,7 @@ fn test_sdram_init_works() {
     sim.add_testbench(move |mut sim: Sim<SDRAMSimulator<5, 5, 10, 16>>| {
         let mut x = sim.init()?;
         let timings = MemoryTimings::fast_boot_sim(125e6);
+        wait_clock_cycles!(sim, clock, x, 16);
         sdram_boot!(sim, clock, x, timings);
         sdram_cmd!(x, SDRAMCommand::LoadModeRegister);
         x.sdram.address.next = 0b000_0_00_011_0_011_u32.into();
