@@ -138,6 +138,9 @@ impl Logic for I2CTestTarget {
                     self.state.d.next = State::Idle;
                 }
             }
+            _ => {
+                self.state.d.next = State::Idle;
+            }
         }
         if self.phy.stop.val() {
             self.state.d.next = State::Idle;
