@@ -225,6 +225,9 @@ impl<const N: usize> Logic for SPIMasterDynamicMode<N> {
                     self.state.d.next = SPIState::LoadBit;
                 }
             }
+            _ => {
+                self.state.d.next = SPIState::Boot;
+            }
         }
     }
 }
